function Model_plots = Run_Model


% Model presented in Mechano-chemical Interactions in Cardiac Sarcomere Contraction: A Computational Modeling Study

% The first calculations are with global parameters to represent all
% [Ca]-Tension curves.

clear


% Independent variables are [Ca] and x
SL_Dobesh = [1.85 1.95 2.05 2.15 2.25];
Ca = [1:0.01:2.27,2.28:0.01:2.58,2.59:0.01:2.82,2.825,2.83:0.01:3.1,3.105,3.12:0.01:3.37,3.38:0.01:3.79, 4, 4.25:0.25:4.75,4.92,5:0.5:5.5,5.6,6:0.5:6.5,6.58,6.75:0.5:9.75,10.02, 11]; % uM
x = [1:1:750]; % nm
x_max = 750; % nm
SOV = Rice_Overlap_fun(SL_Dobesh);
Dob_Ca = [2.27 2.58 2.825 3.105 3.38 3.79 4.25 4.92 5.6 6.58 10.02];
options = odeset('RelTol',1e-6,'AbsTol',1e-4);





%% Alter all parameters per SL
FTC.C_s_a = [9.27 8.66 7.32 4.61 2.73]; 
FTC.K_Ca_a = [10.09 9.46 8.63 7.14 5.73];  
FTC.C_f_a = [0.00185 0.00195 0.00197 0.00196 0.00195];
FTC.n_a = 3;
for j = 1:length(SL_Dobesh)
P_set = [FTC.C_s_a(j) FTC.C_f_a(j) FTC.K_Ca_a(j) FTC.n_a];

for i = 1:length(Ca)

[T,Y] = ode23(@find_ds,(1:1:750),0,options, Ca(i), P_set);
S_array(1:length(Y), i) = Y;
x_array(1:length(T), i) = T;

end

S_pc_array(j, :) = S_array(SOV(j), :);
end




%% Alter only K_TnCa0 per SL
FTC.C_s_k = 6.5;
FTC.C_f_k = 0.00193;
FTC.K_Ca_k = [9.26 8.56 8.18 7.91 7.48];
FTC.n_k = 3;

Ca_test = [3 4 5];
d=ismember(Ca,Ca_test);
Ca_num = find(d);


for j = 1:length(SL_Dobesh)
    
P_set = [FTC.C_s_k FTC.C_f_k FTC.K_Ca_k(j) FTC.n_k];

for i = 1:length(Ca)

[T,Y] = ode23(@find_ds,(1:1:750),0,options, Ca(i), P_set);
S_array(1:length(Y), i) = Y;
x_array(1:length(T), i) = T;

end

S_pk_array(j, :) = S_array(SOV(j), :);
if j==3
    S_pk_x_array = S_array(1:626, Ca_num(1:3));
end
end
S_array = S_pk_array(3,:);





%% Sensitivity to change in n: SL = 2.05 and n=1,2,3
FTC.n_s = [1 2 3];
FTC.C_s_s = [134.90 24.07 7.32];
FTC.C_f_s = [0.00293 0.00220 0.00197];
FTC.K_Ca_s = [618.97 22.14 8.63];

for j = 1:length(FTC.n_s)

P_set = [FTC.C_s_s(j) FTC.C_f_s(j) FTC.K_Ca_s(j) FTC.n_s(j)];


for i = 1:length(Ca)

[T,Y] = ode23(@find_ds,(1:1:750),0,options, Ca(i), P_set);
S_array(1:length(Y), i) = Y;
x_array(1:length(T), i) = T;

end
S_pn_array(j, :) = S_array(625, :);
end


%%
% Plots
D_plot(Ca, S_array, x_array, S_pc_array, S_pk_array, S_pn_array,FTC, S_pk_x_array)

end

