function [dS] = find_ds(~, S, Ca, P_set)
% FTC_ds(x, S, Ca, P_set) = dS
% This function is utilized to simulate the change in tension in the thin filament in a skinned muscle experiment.
% Hence, SL and [Ca] remain constant throughout a simulation. 
% x should be an array representing the length of the single overlap region in nanometers
% S is the tension in the thin filament. This is an output of the model.
% Ca is the calcium concentration.
% P_set is the list of parameters in order [C_s C_f K_Ca]


C_s = P_set(1);
C_f = P_set(2);
K_Ca = P_set(3);
n = P_set(4);

dS = (C_f/(1+exp(n*(-C_s*S - log(Ca/K_Ca)))));